[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[project]
name = "{{ project_name }}"
version = "0.1.0"
description = "Add your description here"
readme = "README.md"
requires-python = ">=3.11"
dependencies = []

[dependency-groups]
dev = [
    "marimo>=0.20.0",
    "numpy>=2.4.2",
    "plotly>=6.5.2",
    "polars>=1.37.1"
]

[tool.hatch.build.targets.wheel]
packages = ["src/{{ package_name }}"]

[tool.deptry]
# see https://deptry.com/usage/#pep-621-dev-dependency-groups
pep621_dev_dependency_groups = ["dev"]

